@@ -118,10 +118,22 @@ class Organizations(Creatable, Queryable, Retrievable, Updatable, Deletable):
 
         Args:
             id: ID of the Organization to be updated.
-            data: Data to be updated.
+            files: Files to be updated.
 
         Returns:
             Organization: The udpated Organization resource.
         """
-        certs = cls._update_certs(id=id, files=files, data=data)
-        return certs
\ No newline at end of file
+        return cast('Organizations', cls._update_certs(id=id, files=files, data=data))
+    
+    @classmethod
+    def upload_logo(cls, id: str, files) -> 'Organizations':
+        """Update an Organization.
+
+        Args:
+            id: ID of the Organization to be updated.
+            files: Files to be updated.
+
+        Returns:
+            Organization: The udpated Organization resource.
+        """
+        return cast('Organizations', cls._update_logo(id=id, files=files))
\ No newline at end of file
